@@ -1,17 +1,9 @@
 /*
- *
- * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
- * Copyright (C) 2011 Michal Malek <michalm@jabster.pl>
- *
- * This file is part of the K3b project.
- * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- * See the file "COPYING" for the exact licensing terms.
- */
+    SPDX-FileCopyrightText: 2011 Michal Malek <michalm@jabster.pl>
+    SPDX-FileCopyrightText: 1998-2007 Sebastian Trueg <trueg@k3b.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef _K3B_CLONE_JOB_H_
 #define _K3B_CLONE_JOB_H_
@@ -34,19 +26,19 @@ namespace K3b {
 
     public:
         explicit CloneJob( JobHandler*, QObject* parent = 0 );
-        ~CloneJob();
+        ~CloneJob() override;
 
-        virtual Device::Device* writer() const { return m_writerDevice; }
+        Device::Device* writer() const override { return m_writerDevice; }
         Device::Device* readingDevice() const { return m_readerDevice; }
 
-        virtual QString jobDescription() const;
-        virtual QString jobDetails() const;
-        virtual QString jobSource() const;
-        virtual QString jobTarget() const;
+        QString jobDescription() const override;
+        QString jobDetails() const override;
+        QString jobSource() const override;
+        QString jobTarget() const override;
 
     public Q_SLOTS:
-        virtual void start();
-        virtual void cancel();
+        void start() override;
+        void cancel() override;
 
         void setWriterDevice( K3b::Device::Device* w ) { m_writerDevice = w; }
         void setReaderDevice( K3b::Device::Device* w ) { m_readerDevice = w; }
